@@ -1,6 +1,7 @@
 import logging
 
 from .__version__ import __version__
+from ._wait import constant, expo, fibo
 
 logger = logging.getLogger("rabbit-client")
 logger.addHandler(logging.NullHandler())
@@ -12,4 +13,14 @@ from rabbit.publish import Publish
 from rabbit.queue import Queue
 from rabbit.subscribe import Subscribe
 
-__all__ = ["AioRabbitClient", "DLX", "Exchange", "Queue", "Publish", "Subscribe"]
+__all__ = [
+    "AioRabbitClient",
+    "DLX",
+    "Exchange",
+    "Queue",
+    "Publish",
+    "Subscribe",
+    "expo",
+    "constant",
+    "fibo",
+]
